@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: toolbox.c 8486 2007-08-29 13:18:38Z yeti-dn $
+ *  @(#) $Id: toolbox.c 8895 2008-12-28 12:19:29Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -702,6 +702,14 @@ gwy_app_menu_create_meta_menu(GtkAccelGroup *accel_group)
             0,
             "<Separator>",
             NULL },
+        {
+            N_("/_Tip of the Day"),
+            NULL,
+            gwy_app_tip_of_the_day,
+            0,
+            "<StockItem>",
+            GTK_STOCK_DIALOG_INFO
+        },
         {
             N_("/_About Gwyddion"),
             NULL,
