@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyselection.c 6520 2006-09-03 19:41:30Z yeti-dn $
+ *  @(#) $Id: gwyselection.c 9267 2009-06-16 13:58:13Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -64,6 +64,11 @@ static void      gwy_selection_set_data_default   (GwySelection *selection,
                                                    const gdouble *data);
 static void  gwy_selection_set_max_objects_default(GwySelection *selection,
                                                    guint max_objects);
+static void      gwy_selection_crop_default       (GwySelection *selection,
+                                                   gdouble xmin,
+                                                   gdouble ymin,
+                                                   gdouble xmax,
+                                                   gdouble ymax);
 static GByteArray* gwy_selection_serialize_default(GObject *obj,
                                                    GByteArray *buffer);
 static gsize     gwy_selection_get_size_default   (GObject *obj);
@@ -96,6 +101,7 @@ gwy_selection_class_init(GwySelectionClass *klass)
     klass->get_data = gwy_selection_get_data_default;
     klass->set_data = gwy_selection_set_data_default;
     klass->set_max_objects = gwy_selection_set_max_objects_default;
+    klass->crop = gwy_selection_crop_default;
 
     g_object_class_install_property
         (gobject_class,
@@ -247,6 +253,72 @@ gwy_selection_clear(GwySelection *selection)
     GWY_SELECTION_GET_CLASS(selection)->clear(selection);
 }
 
+/**
+ * gwy_selection_crop:
+ * @selection: A selection.
+ * @xmin: Minimum x-coordinate.
+ * @ymin: Minimum y-coordinate.
+ * @xmax: Maximum x-coordinate.
+ * @ymax: Maximum y-coordinate.
+ *
+ * Limits objects in a selection to a rectangle.
+ *
+ * Objects that are fully outside specified rectangle are removed.  Objects
+ * partially outside may be removed or cut, depending on what makes sense for
+ * the specific selection type.  If the selection class does not implement this
+ * method then all objects are removed.
+ *
+ * Since: 2.16
+ **/
+void
+gwy_selection_crop(GwySelection *selection,
+                   gdouble xmin,
+                   gdouble ymin,
+                   gdouble xmax,
+                   gdouble ymax)
+{
+    g_return_if_fail(GWY_IS_SELECTION(selection));
+    GWY_SELECTION_GET_CLASS(selection)->crop(selection, xmin, ymin, xmax, ymax);
+}
+
+/**
+ * gwy_selection_filter:
+ * @selection: A selection.
+ * @filter: Function returning %TRUE for objects that should be kept, %FALSE
+ *          for objects that should be removed.
+ * @data: User data passed to @filter.
+ *
+ * Removes selection objects matching certain criteria.
+ *
+ * Since: 2.16
+ **/
+void
+gwy_selection_filter(GwySelection *selection,
+                     GwySelectionFilterFunc filter,
+                     gpointer data)
+{
+    GwySelection *sel;
+    guint len, i, object_size;
+    gdouble *xy;
+
+    /* Be careful to work with non-default implementations.  Do not assume we
+     * know much about the internal structure. */
+    sel = gwy_selection_duplicate(selection);
+    gwy_selection_clear(sel);
+    len = gwy_selection_get_data(selection, NULL);
+    object_size = gwy_selection_get_object_size(selection);
+    xy = g_newa(gdouble, object_size);
+    for (i = 0; i < len; i++) {
+        if (filter(selection, i, data)) {
+            gwy_selection_get_object(selection, i, xy);
+            gwy_selection_set_object(sel, -1, xy);
+        }
+    }
+    /* This is the only place we emit a signal on @selection. */
+    gwy_serializable_clone(G_OBJECT(sel), G_OBJECT(selection));
+    g_object_unref(sel);
+}
+
 /**
  * gwy_selection_get_object:
  * @selection: A selection.
@@ -568,6 +640,18 @@ gwy_selection_set_max_objects_default(GwySelection *selection,
         g_object_notify(G_OBJECT(selection), "max-objects");
 }
 
+static void
+gwy_selection_crop_default(GwySelection *selection,
+                           G_GNUC_UNUSED gdouble xmin,
+                           G_GNUC_UNUSED gdouble ymin,
+                           G_GNUC_UNUSED gdouble xmax,
+                           G_GNUC_UNUSED gdouble ymax)
+{
+    /* If the selection class does not implement crop, we have to remove all
+     * objects. */
+    gwy_selection_clear(selection);
+}
+
 static GByteArray*
 gwy_selection_serialize_default(GObject *obj,
                                 GByteArray *buffer)
@@ -786,4 +870,18 @@ gwy_selection_clone_default(GObject *source, GObject *copy)
  * typecasting.
  **/
 
+/**
+ * GwySelectionFilterFunc:
+ * @selection: A selection.
+ * @i: Index of object to consider.
+ * @data: User data passed to gwy_selection_filter().
+ *
+ * Type of selection filtering function.
+ *
+ * Returns: %TRUE for objects that should be kept, %FALSE for objects that
+ *          should be removed.
+ *
+ * Since: 2.16
+ **/
+
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
