@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwynlfit.c 8238 2007-06-24 21:43:25Z yeti-dn $
+ *  @(#) $Id: gwynlfit.c 8874 2008-12-28 12:16:22Z yeti-dn $
  *  Copyright (C) 2000-2003 Martin Siler.
  *  Copyright (C) 2004,2005 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -284,8 +284,8 @@ gwy_math_nlfit_fit_full(GwyNLFitter *nlfit,
             mlambda *= nlfit->mdec;
             sumr = sumr1;
 
-            memset(a, 0, covar_size*sizeof(gdouble));
-            memset(v, 0, n_var_param*sizeof(gdouble));
+            gwy_clear(a, covar_size);
+            gwy_clear(v, n_var_param);
 
             /* J'J and J'r computation */
             for (i = 0; i < n_dat; i++) {
