@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwynlfitpreset.c 8237 2007-06-24 21:30:37Z yeti-dn $
+ *  @(#) $Id: gwynlfitpreset.c 9222 2009-06-08 19:15:54Z miraval $
  *  Copyright (C) 2000-2003 Martin Siler.
  *  Copyright (C) 2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
@@ -111,6 +111,9 @@ gauss_psdf_guess(gint n_dat,
     gdouble sw, w, xx, l, k2, k4, b0, b2, d, alpha, beta;
     gint i;
 
+    param[0] = 0.0;
+    param[1] = 1.0;
+
     sw = k2 = k4 = b0 = b2 = 0.0;
     for (i = 0; i < n_dat; i++) {
         if (x[i] <= 0.0 || y[i] <= 0.0)
@@ -305,6 +308,9 @@ gauss_acf_guess(gint n_dat,
     gdouble sw, w, xx, l, k2, k4, b0, b2, d, alpha, beta;
     gint i;
 
+    param[0] = 0.0;
+    param[1] = 1.0;
+
     sw = k2 = k4 = b0 = b2 = 0.0;
     for (i = 0; i < n_dat; i++) {
         if (x[i] <= 0.0 || y[i] <= 0.0)
@@ -374,6 +380,9 @@ gauss_rpsdf_guess(gint n_dat,
     gdouble sw, w, xx, l, k2, k4, b0, b2, d, alpha, beta;
     gint i;
 
+    param[0] = 0.0;
+    param[1] = 1.0;
+
     sw = k2 = k4 = b0 = b2 = 0.0;
     for (i = 0; i < n_dat; i++) {
         if (x[i] <= 0.0 || y[i] <= 0.0)
@@ -502,6 +511,10 @@ exp_psdf_guess(gint n_dat,
     gdouble s0, s1, max;
     gint i, n;
 
+    param[0] = 0.0;
+    param[1] = 0.0;
+    param[2] = 0.0;
+
     s0 = s1 = 0.0;
     max = -G_MAXDOUBLE;
     n = 0;
@@ -597,6 +610,10 @@ exp_acf_guess(gint n_dat,
     gdouble sw, w, xx, l, k2, k4, b0, b2, d, alpha, beta;
     gint i;
 
+    param[0] = 0.0;
+    param[1] = 0.0;
+    param[2] = 0.0;
+
     sw = k2 = k4 = b0 = b2 = 0.0;
     for (i = 0; i < n_dat; i++) {
         if (x[i] <= 0.0 || y[i] <= 0.0)
@@ -668,6 +685,10 @@ exp_rpsdf_guess(gint n_dat,
     gdouble s0, sm1, max;
     gint i, n;
 
+    param[0] = 0.0;
+    param[1] = 0.0;
+    param[2] = 0.0;
+
     s0 = sm1 = 0.0;
     max = -G_MAXDOUBLE;
     n = 0;
@@ -861,6 +882,10 @@ power_guess(gint n_dat,
     gint i;
     gdouble q, la, lb, c1, c2;
 
+    param[0] = 0.0;
+    param[1] = 0.0;
+    param[2] = 1.0;
+
     if (n_dat < 4 || x[0] <= 0.0) {
         *fres = FALSE;
         return;
@@ -956,8 +981,13 @@ lorentz_guess(gint n_dat,
               gdouble *param,
               gboolean *fres)
 {
-    gint i, imin, imax;
-    gdouble c0, c2p, c2m;
+    gint i, imin, imax, nv;
+    gdouble c0, cm, vec[5];
+
+    param[0] = 0.0;
+    param[1] = 0.0;
+    param[2] = 0.0;
+    param[3] = 1.0;
 
     imin = imax = 0;
     for (i = 1; i < n_dat; i++) {
@@ -967,36 +997,34 @@ lorentz_guess(gint n_dat,
             imin = i;
     }
 
-    c0 = c2p = c2m = 0.0;
-    for (i = 0; i < n_dat; i++) {
+    c0 = 0.0;
+    for (i = 0; i < n_dat; i++)
         c0 += y[i];
-        c2p += y[i]*(x[i] - x[imax])*(x[i] - x[imax]);
-        c2m += y[i]*(x[i] - x[imin])*(x[i] - x[imin]);
-    }
-    c0 *= (x[n_dat-1] - x[0])/n_dat;
-    c2p *= (x[n_dat-1] - x[0])/n_dat;
-    c2m *= (x[n_dat-1] - x[0])/n_dat;
+    c0 /= n_dat;
 
-    param[2] = c2p/(c0/y[imax] + x[n_dat-1] - x[0]);
-    if (param[2]*y[imax] > 0.0) {
-        param[3] = sqrt(param[2]/y[imax]);
+    nv = G_N_ELEMENTS(vec);
+    for (i = 0; i < nv; i++)
+        vec[i] = y[i*(n_dat - 1)/(nv - 1)];
+    cm = gwy_math_median(nv, vec);
+
+    if (cm - y[imin] < y[imax] - cm) {
+        param[0] = y[imin];
         param[1] = x[imax];
     }
     else {
-        param[2] = c2m/(c0/y[imin] + x[n_dat-1] - x[0]);
-        if (param[2]*y[imin] > 0.0) {
-            param[3] = sqrt(param[2]/y[imin]);
-            param[1] = x[imin];
-        }
-        else {
-            *fres = FALSE;
-            return;
-        }
-    }
-    if (param[2] > 0.0)
-        param[0] = y[imin];
-    else
         param[0] = y[imax];
+        param[1] = x[imin];
+    }
+
+    c0 = c0 - param[0];
+    c0 *= fabs(x[n_dat-1] - x[0]);
+    c0 /= G_PI;
+    param[2] = c0*fabs(c0)/(y[imax] - y[imin]);
+
+    if (c0)
+        param[3] = param[2]/c0;
+    else
+        param[3] = fabs(x[n_dat-1] - x[0])/4.0;
 
     *fres = TRUE;
 }
@@ -1159,7 +1187,7 @@ static const GwyNLFitParam sinc_params[] = {
 
 static const GwyNLFitPresetBuiltin fitting_presets[] = {
     {
-        "Gaussian",
+        N_("Gaussian"),
         "<i>f</i>(<i>x</i>) "
             "= <i>y</i><sub>0</sub> "
             "+ <i>a</i> exp[−(<i>x</i> "
@@ -1175,7 +1203,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_params,
     },
     {
-        "Gaussian (PSDF)",
+        N_("Gaussian (PSDF)"),
         "<i>f</i>(<i>x</i>) "
             "= σ<sup>2</sup><i>T</i>/(2√π) "
             "exp[−(<i>x</i><i>T</i>/2)<sup>2</sup>]",
@@ -1189,7 +1217,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Gaussian (ACF)",
+        N_("Gaussian (ACF)"),
         "<i>f</i>(<i>x</i>) "
             "= σ<sup>2</sup> "
             "exp[−(<i>x</i>/<i>T</i>)<sup>2</sup>]",
@@ -1203,7 +1231,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Gaussian (HHCF)",
+        N_("Gaussian (HHCF)"),
         "<i>f</i>(<i>x</i>) "
             "= 2σ<sup>2</sup>"
             "[1 − exp(−(<i>x</i>/<i>T</i>)<sup>2</sup>)]",
@@ -1217,7 +1245,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Gaussian (RPSDF)",
+        N_("Gaussian (RPSDF)"),
         "<i>f</i>(<i>x</i>) "
             "= (σ<i>T</i>)<sup>2</sup>/2 "
             "<i>x</i> exp[−(<i>x</i><i>T</i>/2)<sup>2</sup>]",
@@ -1231,7 +1259,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Exponential",
+        N_("Exponential"),
         "<i>f</i>(<i>x</i>) "
             "= <i>y</i><sub>0</sub> + <i>a</i> exp(<i>x</i>/<i>b</i>)",
         &exp_func,
@@ -1244,7 +1272,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         exp_params,
     },
     {
-        "Exponential (PSDF)",
+        N_("Exponential (PSDF)"),
         "<i>f</i>(<i>x</i>) "
             "= σ<sup>2</sup><i>T</i>/π "
             "1/[1 + <i>x</i><sup>2</sup><i>T</i><sup>2</sup>]",
@@ -1258,7 +1286,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Exponential (ACF)",
+        N_("Exponential (ACF)"),
         "<i>f</i>(<i>x</i>) "
             "= σ<sup>2</sup> exp[−<i>x</i>/<i>T</i>]",
         &exp_acf_func,
@@ -1271,7 +1299,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Exponential (HHCF)",
+        N_("Exponential (HHCF)"),
         "<i>f</i>(<i>x</i>) "
             "= 2σ<sup>2</sup>"
             "[1 − exp(−<i>x</i>/<i>T</i>)]",
@@ -1285,7 +1313,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Exponential (RPSDF)",
+        N_("Exponential (RPSDF)"),
         "<i>f</i>(<i>x</i>) "
             "= σ<sup>2</sup><i>T</i> "
             "<i>xT</i>/[1 + <i>x</i><sup>2</sup><i>T</i><sup>2</sup>]"
@@ -1300,7 +1328,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         gauss_two_params,
     },
     {
-        "Polynomial (order 0)",
+        N_("Polynomial (order 0)"),
         "<i>f</i>(<i>x</i>) = <i>a</i>",
         &poly_0_func,
         NULL,
@@ -1312,7 +1340,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         poly3_params,
     },
     {
-        "Polynomial (order 1)",
+        N_("Polynomial (order 1)"),
         "<i>f</i>(<i>x</i>) = <i>a</i> + <i>b</i><i>x</i>",
         &poly_1_func,
         NULL,
@@ -1324,7 +1352,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         poly3_params,
     },
     {
-        "Polynomial (order 2)",
+        N_("Polynomial (order 2)"),
         "<i>f</i>(<i>x</i>) "
             "= <i>a</i> + <i>b</i><i>x</i> + <i>c</i><i>x</i><sup>2</sup>",
         &poly_2_func,
@@ -1337,7 +1365,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         poly3_params,
     },
     {
-        "Polynomial (order 3)",
+        N_("Polynomial (order 3)"),
         "<i>f</i>(<i>x</i>) "
             "= <i>a</i> + <i>b</i><i>x</i> + <i>c</i><i>x</i><sup>2</sup> "
             "+ <i>d</i><i>x</i><sup>3</sup>",
@@ -1351,7 +1379,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         poly3_params,
     },
     {
-        "Square wave",
+        N_("Square wave"),
         "<i>f</i>(<i>x</i>) "
             "= (<i>t</i> + <i>b</i>)/2 "
             "+ 2(<i>t</i> − <i>b</i>)"
@@ -1368,7 +1396,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         square_params,
     },
     {
-        "Power",
+        N_("Power"),
         "<i>f</i>(<i>x</i>) "
             "= <i>a</i> + <i>b</i><i>x</i><sup><i>c</i></sup>",
         &power_func,
@@ -1381,7 +1409,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         power_params,
     },
     {
-        "Lorentzian",
+        N_("Lorentzian"),
         "<i>f</i>(<i>x</i>) "
             "= <i>y</i><sub>0</sub> "
             "+ <i>a</i>/[<i>b</i><sup>2</sup> "
@@ -1396,7 +1424,7 @@ static const GwyNLFitPresetBuiltin fitting_presets[] = {
         lorentz_params,
     },
     {
-        "Sinc",
+        N_("Sinc"),
         "<i>f</i>(<i>x</i>) "
             "= <i>a</i> sinc(<i>x</i>/<i>b</i>)",
         &sinc_func,
@@ -1587,6 +1615,9 @@ gwy_nlfit_preset_get_nparams(GwyNLFitPreset* preset)
  * absolute guarantee of quality, however if the data points approximately
  * match the fitted function the fit will typically converge from the returned
  * estimate.
+ *
+ * The parameters are filled also on failure, though just with some neutral
+ * values that should not give raise to NaNs and infinities.
  **/
 void
 gwy_nlfit_preset_guess(GwyNLFitPreset *preset,
@@ -1771,7 +1802,7 @@ gwy_nlfit_presets(void)
  * /&ast; Use a priori parameter value information, or: &ast;/
  * gwy_nlfit_preset_guess(preset, ndata, xdata, ydata, params, &ok);
  * fitter = gwy_nlfit_preset_fit(preset, NULL,
- *                               ndata, xdata, ydata, params, 
+ *                               ndata, xdata, ydata, params,
  *                               params, errors, NULL);
  *
  * /&ast; Examine fitting status, parameters and errors... &ast;/
