@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyserializable.c 7737 2007-03-18 20:13:56Z yeti-dn $
+ *  @(#) $Id: gwyserializable.c 8874 2008-12-28 12:16:22Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1388,7 +1388,7 @@ gwy_deserialize_hash_items(const guchar *buffer,
     sp.array_size = &it.array_size;
     sp.value = &it.value;
     while (position < size) {
-        memset(&it, 0, sizeof(it));
+        gwy_clear(&it, 1);
         nlen = gwy_serialize_check_string(buffer, size, position, NULL);
         if (!nlen) {
             g_warning("Expected a component name to deserialize, got garbage");
