@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwyutils.c 8914 2008-12-30 12:45:34Z yeti-dn $
+ *  @(#) $Id: gwyutils.c 9172 2009-05-18 17:44:34Z yeti-dn $
  *  Copyright (C) 2003-2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -351,7 +351,7 @@ gwy_memmem(gconstpointer haystack,
     /* The general case */
     n0 = *(const guchar*)needle;
     s = h + haystack_len - needle_len;
-    for (p = h; p <= s; p = memchr(p, n0, s-p + 1)) {
+    for (p = h; p && p <= s; p = memchr(p, n0, s-p + 1)) {
         if (memcmp(p, needle, needle_len) == 0)
             return (gpointer)p;
         p++;
