@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwy3dview.c 8511 2007-09-07 22:15:27Z yeti-dn $
+ *  @(#) $Id: gwy3dview.c 9125 2009-04-14 12:51:23Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *  Copyright (C) 2004 Martin Siler.
@@ -162,6 +162,9 @@ static gboolean gwy_3d_view_configure            (GtkWidget *widget,
 static void     gwy_3d_view_send_configure       (Gwy3DView *gwy3dview);
 static gboolean gwy_3d_view_button_press         (GtkWidget *widget,
                                                   GdkEventButton *event);
+static void     gwy_3d_calculate_pixel_sizes     (GwyDataField *dfield,
+                                                  GLfloat *dx,
+                                                  GLfloat *dy);
 static Gwy3DVector* gwy_3d_make_normals          (GwyDataField *dfield,
                                                   Gwy3DVector *normals);
 static gboolean gwy_3d_view_motion_notify        (GtkWidget *widget,
@@ -202,6 +205,8 @@ labels[GWY_3D_VIEW_NLABELS] = {
 };
 #endif /* HAVE_GTKGLEXT */
 
+static gboolean ugly_hack_globally_disable_axis_drawing = FALSE;
+
 G_DEFINE_TYPE(Gwy3DView, gwy_3d_view, GTK_TYPE_WIDGET)
 
 #ifdef HAVE_GTKGLEXT
@@ -433,6 +438,11 @@ gwy_3d_view_unrealize(GtkWidget *widget)
 
     gwy3dview = GWY_3D_VIEW(widget);
 
+    if (gwy3dview->timeout_id) {
+         g_source_remove(gwy3dview->timeout_id);
+         gwy3dview->timeout_id = 0;
+    }
+
     gwy_3d_view_release_lists(gwy3dview);
     gwy_object_unref(gwy3dview->downsampled);
 
@@ -602,7 +612,7 @@ gwy_3d_view_set_data_key(Gwy3DView *gwy3dview,
 const gchar*
 gwy_3d_view_get_data_key(Gwy3DView *gwy3dview)
 {
-    g_return_val_if_fail(GWY_IS_LAYER_BASIC(gwy3dview), NULL);
+    g_return_val_if_fail(GWY_IS_3D_VIEW(gwy3dview), NULL);
     return g_quark_to_string(gwy3dview->data_key);
 }
 
@@ -1661,6 +1671,52 @@ gwy_3d_view_motion_notify(GtkWidget *widget,
     return FALSE;
 }
 
+/**
+ * gwy_3d_calculate_pixel_sizes:
+ * @dfield: A data field.
+ * @pdx: Location to store x-direction step, or NULL.
+ * @pdy: Location to store y-direction step, or NULL.
+ *
+ * Calculates pixel sizes used for visualization.
+ *
+ * The smaller step of @pdx and @pdy is always 1.0, which mean the GL dimension
+ * will be equal to the resolution.  The larger is calculated to keep the
+ * physical aspect ratio.
+ **/
+static void
+gwy_3d_calculate_pixel_sizes(GwyDataField *dfield,
+                             GLfloat *dx,
+                             GLfloat *dy)
+{
+   gint xres, yres;
+   gdouble xreal, yreal;
+
+   xres = gwy_data_field_get_xres(dfield);
+   yres = gwy_data_field_get_yres(dfield);
+   xreal = gwy_data_field_get_xreal(dfield);
+   yreal = gwy_data_field_get_yreal(dfield);
+   /* The smaller triangle side is 1.0, the larger is, well, at least that.
+    * To get pixel-wise behaviour, just set dx=dy=1. */
+   if (xres/xreal <= yres/yreal) {
+       *dx = (yres/yreal)/(xres/xreal);
+       *dy = 1.0;
+   }
+   else {
+       *dx = 1.0;
+       *dy = (xres/xreal)/(yres/yreal);
+   }
+}
+
+/**
+ * gwy_3d_make_normals:
+ * @dfield: A data field.
+ * @normals: Array of normals to fill.  It must have the same number of
+ *           elements as @dfield.
+ *
+ * Calculates surface normals used for visualization.
+ *
+ * Returns: @normals again, %NULL if when memory could not be allocated.
+ **/
 static Gwy3DVector*
 gwy_3d_make_normals(GwyDataField *dfield,
                     Gwy3DVector *normals)
@@ -1668,6 +1724,7 @@ gwy_3d_make_normals(GwyDataField *dfield,
    typedef struct { Gwy3DVector A, B; } RectangleNorm;
    const gdouble *data;
    gint i, j, xres, yres;
+   GLfloat dx, dy, dx2, dy2;
    RectangleNorm * norms;
 
    g_return_val_if_fail(normals, NULL);
@@ -1675,6 +1732,9 @@ gwy_3d_make_normals(GwyDataField *dfield,
    xres = gwy_data_field_get_xres(dfield);
    yres = gwy_data_field_get_yres(dfield);
    data = gwy_data_field_get_data_const(dfield);
+   gwy_3d_calculate_pixel_sizes(dfield, &dx, &dy);
+   dx2 = dx*dx;
+   dy2 = dy*dy;
 
    /* memory for normals of triangles
     * total count of rectangels is (xres-1)*(yres-1), each one has 2n triangles
@@ -1684,30 +1744,34 @@ gwy_3d_make_normals(GwyDataField *dfield,
    if (norms == NULL)
        return NULL;
 
-   /* Calculation of nornals of triangles */
+   /* Calculation of normals of triangles */
    for (j = 0; j < yres-1; j++) {
       for (i = 0; i < xres-1; i++) {
-         GLfloat a, b, c, n;
+         GLfloat a, b, c, ab, ac, bc, n;
 
          a = data[(yres-1 - j)*xres + i];
          b = data[(yres-2 - j)*xres + i];
          c = data[(yres-1 - j)*xres + i+1];
-         n = 1.0 / sqrt((a-c)*(a-c) + (b-a)*(b-a) + 1.0);
-         norms[j*(xres-1) + i].A.x = (a-c)*n;
-         norms[j*(xres-1) + i].A.y = (b-a)*n;
-         norms[j*(xres-1)+ i].A.z = n;
+         ab = a - b;
+         ac = a - c;
+         n = 1.0/sqrt(dy2*ac*ac + dx2*ab*ab + dx2*dy2);
+         norms[j*(xres-1) + i].A.x = dy*ac*n;
+         norms[j*(xres-1) + i].A.y = -dx*ab*n;
+         norms[j*(xres-1)+ i].A.z = dx*dy*n;
 
          a = b;
          b = c;
          c = data[(yres-2 - j)*xres + i+1];
-         n = 1.0 / sqrt((a-c)*(a-c) + (c-b)*(c-b) + 1.0);
-         norms[j*(xres-1) + i].B.x = (a-c)*n;
-         norms[j*(xres-1) + i].B.y = (c-b)*n;
-         norms[j*(xres-1) + i].B.z = n;
+         ac = a - c;
+         bc = b - c;
+         n = 1.0/sqrt(dy2*ac*ac + dx2*bc*bc + dx2*dy2);
+         norms[j*(xres-1) + i].B.x = dy*ac*n;
+         norms[j*(xres-1) + i].B.y = -bc*dx*n;
+         norms[j*(xres-1) + i].B.z = dx*dy*n;
       }
    }
 
-   /* two of corner vertecies have only one triangle adjacent
+   /* two of corner vertices have only one triangle adjacent
     * (first and last vertex) */
    normals[0] = norms[0].A;
    normals[xres * yres - 1] = norms[(xres-1) * (yres-1) - 1].B;
@@ -1721,7 +1785,7 @@ gwy_3d_make_normals(GwyDataField *dfield,
                                   + norms[(xres - 1)*(yres -2)].B.y)/2.0f;
    normals[xres * (yres -1)].z = (norms[xres - 2].A.z
                                   + norms[(xres - 1)*(yres -2)].B.z)/2.0f;
-   /*the vertexies on the edge og the matrix have three adjacent triangles*/
+   /*the vertices on the edge of the matrix have three adjacent triangles*/
    for (i = 1; i < xres - 1; i ++) {
        const Gwy3DVector *a = &(norms[i-1].A);
        const Gwy3DVector *b = &(norms[i-1].B);
@@ -1762,7 +1826,7 @@ gwy_3d_make_normals(GwyDataField *dfield,
        normals[i * xres - 1].z = (a->z + b->z + c->z)/3.0;
    }
 
-   /* The vertecies inside of matrix have six adjacent triangles*/
+   /* The vertices inside of matrix have six adjacent triangles*/
    for (j = 1; j < yres - 1; j++) {
        for (i = 1; i < xres - 1; i++) {
            Gwy3DVector *adj_tri[6];
@@ -1798,9 +1862,10 @@ gwy_3d_make_list(Gwy3DView *gwy3dview,
                  GwyDataField *dfield,
                  gint shape)
 {
-    gint i, j, xres, yres, res;
-    gdouble data_min, data_max;
+    gint i, j, xres, yres;
+    gdouble data_min, data_max, res;
     GLdouble zdifr;
+    GLfloat dx, dy;
     Gwy3DVector *normals;
     const gdouble *data;
     GwyGradient *grad;
@@ -1813,23 +1878,25 @@ gwy_3d_make_list(Gwy3DView *gwy3dview,
     yres = gwy_data_field_get_yres(dfield);
     gwy_data_field_get_min_max(gwy3dview->data_field, &data_min, &data_max);
     data = gwy_data_field_get_data_const(dfield);
-    res  = xres > yres ? xres : yres;
     grad = gwy3dview->gradient;
     if (!grad)
         grad = gwy_gradients_get_gradient(NULL);
 
-    glNewList(gwy3dview->shape_list_base + shape, GL_COMPILE);
-    glPushMatrix();
-    glTranslatef(-(xres/(double)res), -(yres/(double)res),
-                 GWY_3D_Z_DISPLACEMENT);
-    glScalef(2.0/res, 2.0/res, GWY_3D_Z_TRANSFORMATION/(data_max - data_min));
-    glTranslatef(0.0, 0.0, -data_min);
-    zdifr = 1.0/(data_max - data_min);
     normals = g_new(Gwy3DVector, xres * yres);
     if (!gwy_3d_make_normals(dfield, normals)) {
         /*TODO solve not enough memory problem*/
+        g_return_if_reached();
     }
 
+    gwy_3d_calculate_pixel_sizes(dfield, &dx, &dy);
+    res = MAX(xres*dx, yres*dy);
+    glNewList(gwy3dview->shape_list_base + shape, GL_COMPILE);
+    glPushMatrix();
+    glTranslatef(-xres*dx/res, -yres*dy/res, GWY_3D_Z_DISPLACEMENT);
+    glScalef(2.0/res, 2.0/res, GWY_3D_Z_TRANSFORMATION/(data_max - data_min));
+    glTranslatef(0.0, 0.0, -data_min);
+    zdifr = 1.0/(data_max - data_min);
+
     /* FIXME: This should be avoided in lighting visualization mode, create
      * it only upon a switch to gradient mode. */
     for (j = 0; j < yres-1; j++) {
@@ -1844,13 +1911,13 @@ gwy_3d_make_list(Gwy3DView *gwy3dview,
                        normals[j*xres+i].z);
             gwy_gradient_get_color(grad, (a - data_min)*zdifr, &color);
             glColor3d(color.r , color.g, color.b);
-            glVertex3d((double)i, (double)j, a);
+            glVertex3d(i*dx, j*dy, a);
             glNormal3d(normals[(j+1)*xres+i].x,
                        normals[(j+1)*xres+i].y,
                        normals[(j+1)*xres+i].z);
             gwy_gradient_get_color(grad, (b - data_min)*zdifr, &color);
             glColor3d(color.r , color.g, color.b);
-            glVertex3d((double)i, (double)(j+1), b);
+            glVertex3d(i*dx, (j+1)*dy, b);
         }
         glEnd();
     }
@@ -1863,7 +1930,7 @@ gwy_3d_make_list(Gwy3DView *gwy3dview,
 static void
 gwy_3d_draw_axes(Gwy3DView *widget)
 {
-    GLfloat rx, Ax, Ay, Bx, By, Cx, Cy;
+    GLfloat dx, dy, rx, Ax, Ay, Bx, By, Cx, Cy;
     gdouble data_min, data_max;
     gint xres, yres, res;
     gboolean yfirst;
@@ -1874,7 +1941,8 @@ gwy_3d_draw_axes(Gwy3DView *widget)
     xres = gwy_data_field_get_xres(widget->data_field);
     yres = gwy_data_field_get_yres(widget->data_field);
     gwy_data_field_get_min_max(widget->data_field, &data_min, &data_max);
-    res  = xres > yres ? xres : yres;
+    gwy_3d_calculate_pixel_sizes(widget->data_field, &dx, &dy);
+    res = MAX(xres*dx, yres*dy);
 
     Ax = Ay = Bx = By = Cx = Cy = 0.0f;
     yfirst = TRUE;
@@ -1885,8 +1953,7 @@ gwy_3d_draw_axes(Gwy3DView *widget)
     mat_none = gwy_gl_materials_get_gl_material(GWY_GL_MATERIAL_NONE);
 
     glPushMatrix();
-    glTranslatef(-(xres/(double)res), -(yres/(double)res),
-                 GWY_3D_Z_DISPLACEMENT);
+    glTranslatef(-dx*xres/res, -dy*yres/res, GWY_3D_Z_DISPLACEMENT);
     glScalef(2.0/res, 2.0/res, GWY_3D_Z_TRANSFORMATION/(data_max - data_min));
     gwy_3d_view_rgba_dv(GL_FRONT, GL_AMBIENT,
                         gwy_gl_material_get_ambient(mat_none));
@@ -1898,24 +1965,24 @@ gwy_3d_draw_axes(Gwy3DView *widget)
                 (GLfloat)gwy_gl_material_get_shininess(mat_none)*128.0f);
 
     if (rx >= 0.0 && rx <= 90.0) {
-        Ay = yres;
-        Cx = xres;
+        Ay = dy*yres;
+        Cx = dx*xres;
         yfirst = TRUE;
     } else if (rx > 90.0 && rx <= 180.0) {
-        Ax = xres;
-        Ay = yres;
-        By = yres;
+        Ax = dx*xres;
+        Ay = dy*yres;
+        By = dy*yres;
         yfirst = FALSE;
     } else if (rx > 180.0 && rx <= 270.0) {
-        Ax = xres;
-        Bx = xres;
-        By = yres;
-        Cy = yres;
+        Ax = dx*xres;
+        Bx = dx*xres;
+        By = dy*yres;
+        Cy = dy*yres;
        yfirst = TRUE;
     } else if (rx >= 270.0 && rx <= 360.0) {
-        Bx = xres;
-        Cx = xres;
-        Cy = yres;
+        Bx = dx*xres;
+        Cx = dx*xres;
+        Cy = dy*yres;
         yfirst = FALSE;
     }
     glBegin(GL_LINE_STRIP);
@@ -1955,7 +2022,8 @@ gwy_3d_draw_axes(Gwy3DView *widget)
     TODO: create bitmaps with labels in the beginning (possibly in init_gl)
           into display lists and draw here
     */
-    if (widget->setup->labels_visible) {
+    if (widget->setup->labels_visible
+        && !ugly_hack_globally_disable_axis_drawing) {
         guint view_size;
         gint size;
 
@@ -2576,6 +2644,26 @@ gwy_3d_view_set_scale_range(G_GNUC_UNUSED Gwy3DView *gwy3dview,
 }
 #endif /* HAVE_GTKGLEXT */
 
+/**
+ * gwy_3d_view_class_disable_axis_drawing:
+ * @disable: %TRUE to disable 3D view axes globally, %FALSE to enable them.
+ *
+ * Globally disables drawing of 3D view axes.
+ *
+ * If axis drawing is disabled, axes are never drawn.  If it is not disabled,
+ * their rendering depends on the 3D view setup.
+ *
+ * This function is a hack and exists to work around various GL implementations
+ * that crash on pixmap drawing operations.
+ *
+ * Since: 2.14
+ **/
+void
+gwy_3d_view_class_disable_axis_drawing(gboolean disable)
+{
+    ugly_hack_globally_disable_axis_drawing = disable;
+}
+
 /************************** Documentation ****************************/
 
 /**
