@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygrapharea.c 7857 2007-04-08 11:09:25Z yeti-dn $
+ *  @(#) $Id: gwygrapharea.c 9039 2009-03-07 20:53:54Z klapetek $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -1524,13 +1524,14 @@ scr_to_data_x(GtkWidget *widget, gint scr)
 
     scr = CLAMP(scr, 0, widget->allocation.width-1);
     g_object_get(model, "x-logarithmic", &lg, NULL);
-    if (!lg)
+    if (!lg) 
         return area->x_min + scr*(area->x_max
                                   - area->x_min) /(widget->allocation.width-1);
-    else
+    else 
         return pow(10, log10(area->x_min)
-                   + scr*(log10(area->x_max
-                                - log10(area->x_min)))/(widget->allocation.width-1));
+                   + scr*(log10(area->x_max)
+                                - log10(area->x_min))/(widget->allocation.width-1));
+
 }
 
 static void
