@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: gwygraphcurvemodel.c 8520 2007-09-09 21:49:20Z yeti-dn $
+ *  @(#) $Id: gwygraphcurvemodel.c 8953 2009-01-02 12:03:16Z yeti-dn $
  *  Copyright (C) 2005-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -303,7 +303,7 @@ gwy_graph_curve_model_init(GwyGraphCurveModel *gcmodel)
     gwy_debug("");
     gwy_debug_objects_creation((GObject*)gcmodel);
 
-    gcmodel->description = g_string_new("");
+    gcmodel->description = g_string_new(NULL);
     gcmodel->color.r = 0;
     gcmodel->color.g = 0;
     gcmodel->color.b = 0;
@@ -642,7 +642,7 @@ gwy_graph_curve_model_set_data_from_dataline(GwyGraphCurveModel *gcmodel,
 
     offset = gwy_data_line_get_offset(dline);
 
-    ldata = gwy_data_line_get_data(dline);
+    ldata = gwy_data_line_get_data_const(dline);
     for (i = 0; i < res; i++) {
         xdata[i] = realmin + i*(realmax - realmin)/res + offset;
         ydata[i] = ldata[i + from_index];
