@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: datafield.c 8954 2009-01-02 12:04:03Z yeti-dn $
+ *  @(#) $Id: datafield.c 9023 2009-02-27 10:48:18Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -2072,7 +2072,7 @@ gwy_data_field_get_profile(GwyDataField *data_field,
                          && erow < data_field->yres && ecol < data_field->xres,
                          NULL);
 
-    size = hypot(scol - ecol, srow - erow);
+    size = hypot(abs(scol - ecol) + 1, abs(srow - erow) + 1);
     size = MAX(size, 1.0);
     if (res <= 0)
         res = GWY_ROUND(size);
