@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: level.c 8202 2007-06-22 20:17:43Z yeti-dn $
+ *  @(#) $Id: level.c 8885 2008-12-28 12:17:52Z yeti-dn $
  *  Copyright (C) 2003 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -281,6 +281,91 @@ gwy_data_field_plane_rotate(GwyDataField *data_field,
     gwy_data_field_invalidate(data_field);
 }
 
+#if 0
+void
+gwy_data_field_plane_true_rotate(GwyDataField *data_field,
+                                 gdouble xangle,
+                                 gdouble yangle,
+                                 GwyInterpolationType interpolation)
+{
+    gdouble diag, dx, dy, phi, phi0, theta, tx, ty;
+    gint xres, yres, txres, tyres, xbw, ybw, i;
+    gdouble *data, *tdata;
+    GwyDataField *tmp;
+
+    if (xangle == 0 || yangle == 0) {
+        gwy_data_field_plane_rotate(data_field, xangle, yangle, interpolation);
+        return;
+    }
+
+    xres = data_field->xres;
+    yres = data_field->yres;
+    data = data_field->data;
+
+    dx = tan(xangle);
+    dy = tan(yangle);
+    phi = atan2(dy, dx);
+    theta = atan(hypot(dx, dy));
+    phi0 = atan2(yres, xres);
+    diag = hypot(xres, yres);
+    tx = MAX(fabs(cos(-phi + phi0)), fabs(cos(-phi - phi0)));
+    ty = MAX(fabs(sin(-phi + phi0)), fabs(sin(-phi - phi0)));
+    txres = ((guint)GWY_ROUND(diag*tx + 2));
+    tyres = ((guint)GWY_ROUND(diag*ty + 2));
+    /* Keep parity to make the rotation less fuzzy */
+    xbw = (txres - xres + 1)/2;
+    if (xres + 2*xbw != txres)
+        txres++;
+    ybw = (tyres - yres + 1)/2;
+    if (yres + 2*ybw != tyres)
+        tyres++;
+
+    /* Rotate to a temporary data field extended with border pixels */
+    tmp = gwy_data_field_new(txres, tyres, 1.0, 1.0, FALSE);
+    tdata = tmp->data;
+    /* Copy */
+    gwy_data_field_area_copy(data_field, tmp, 0, 0, xres, yres, xbw, ybw);
+    /* Corners */
+    gwy_data_field_area_fill(tmp, 0, 0, xbw, ybw,
+                             data[0]);
+    gwy_data_field_area_fill(tmp, xres + xbw, 0, xbw, ybw,
+                             data[xres-1]);
+    gwy_data_field_area_fill(tmp, 0, yres + ybw, xbw, ybw,
+                             data[xres*(yres - 1)]);
+    gwy_data_field_area_fill(tmp, xres + xbw, yres + ybw, xbw, ybw,
+                             data[xres*yres - 1]);
+    /* Sides */
+    for (i = 0; i < ybw; i++)
+        memcpy(tdata + i*txres + xbw, data,
+               xres*sizeof(gdouble));
+    for (i = 0; i < ybw; i++)
+        memcpy(tdata + (yres + ybw + i)*txres + xbw, data + xres*(yres - 1),
+               xres*sizeof(gdouble));
+    for (i = 0; i < yres; i++) {
+        gwy_data_field_area_fill(tmp, 0, ybw + i, xbw, 1,
+                                 data[i*xres]);
+        gwy_data_field_area_fill(tmp, xres + xbw, ybw + i, xbw, 1,
+                                 data[i*xres + xres - 1]);
+    }
+
+    /* Rotate in xy to make the space rotation along y axis */
+    gwy_data_field_rotate(tmp, -phi, interpolation);
+    /* XXX: Still, individual gwy_data_line_rotate() can resample differently,
+     * causing incompatible rows in the image.  And we cannot get the
+     * resampling information from gwy_data_line_rotate(). */
+    gwy_data_field_plane_rotate(tmp, theta, 0, GWY_INTERPOLATION_LINEAR);
+    /* TODO:
+     * recalculate xres
+     * make samples square again
+     */
+    gwy_data_field_rotate(tmp, phi, interpolation);
+    /* XXX: xbw is no longer correct border */
+    gwy_data_field_area_copy(tmp, data_field, xbw, ybw, xres, yres, 0, 0);
+
+    g_object_unref(tmp);
+}
+#endif
+
 /**
  * gwy_data_field_fit_lines:
  * @data_field: A data field.
@@ -442,7 +527,7 @@ gwy_data_field_area_fit_polynom(GwyDataField *data_field,
     if (!coeffs)
         coeffs = g_new0(gdouble, size);
     else
-        memset(coeffs, 0, size*sizeof(gdouble));
+        gwy_clear(coeffs, size);
 
     sums = g_new0(gdouble, (2*row_degree+1)*(2*col_degree+1));
     for (r = row; r < row + height; r++) {
@@ -487,7 +572,7 @@ gwy_data_field_area_fit_polynom(GwyDataField *data_field,
     }
 
     if (!gwy_math_choleski_decompose(size, m))
-        memset(coeffs, 0, size*sizeof(gdouble));
+        gwy_clear(coeffs, size);
     else
         gwy_math_choleski_solve(size, m, coeffs);
 
@@ -687,7 +772,7 @@ gwy_data_field_area_fit_legendre(GwyDataField *data_field,
     if (!coeffs)
         coeffs = g_new0(gdouble, size);
     else
-        memset(coeffs, 0, size*sizeof(gdouble));
+        gwy_clear(coeffs, size);
 
     sumsx = g_new0(gdouble, col_n*col_n);
     sumsy = g_new0(gdouble, row_n*row_n);
@@ -759,7 +844,7 @@ gwy_data_field_area_fit_legendre(GwyDataField *data_field,
         }
         /* Solve */
         if (!gwy_math_choleski_decompose(thissize, m)) {
-            memset(coeffs, 0, size*sizeof(gdouble));
+            gwy_clear(coeffs, size);
             goto fail;
         }
         gwy_math_choleski_solve(thissize, m, rhs);
@@ -799,7 +884,7 @@ gwy_data_field_area_fit_legendre(GwyDataField *data_field,
         }
         /* Solve */
         if (!gwy_math_choleski_decompose(thissize, m)) {
-            memset(coeffs, 0, size*sizeof(gdouble));
+            gwy_clear(coeffs, size);
             goto fail;
         }
         gwy_math_choleski_solve(thissize, m, rhs);
@@ -839,7 +924,7 @@ gwy_data_field_area_fit_legendre(GwyDataField *data_field,
         }
         /* Solve */
         if (!gwy_math_choleski_decompose(thissize, m)) {
-            memset(coeffs, 0, size*sizeof(gdouble));
+            gwy_clear(coeffs, size);
             goto fail;
         }
         gwy_math_choleski_solve(thissize, m, rhs);
@@ -879,7 +964,7 @@ gwy_data_field_area_fit_legendre(GwyDataField *data_field,
         }
         /* Solve */
         if (!gwy_math_choleski_decompose(thissize, m)) {
-            memset(coeffs, 0, size*sizeof(gdouble));
+            gwy_clear(coeffs, size);
             goto fail;
         }
         gwy_math_choleski_solve(thissize, m, rhs);
@@ -1068,7 +1153,7 @@ gwy_data_field_area_fit_poly_max(GwyDataField *data_field,
     if (!coeffs)
         coeffs = g_new0(gdouble, size);
     else
-        memset(coeffs, 0, size*sizeof(gdouble));
+        gwy_clear(coeffs, size);
 
     sumsx = g_new0(gdouble, degree_n*degree_n);
     sumsy = g_new0(gdouble, degree_n*degree_n);
@@ -1133,7 +1218,7 @@ gwy_data_field_area_fit_poly_max(GwyDataField *data_field,
     }
     /* Solve */
     if (!gwy_math_choleski_decompose(size, m)) {
-        memset(coeffs, 0, size*sizeof(gdouble));
+        gwy_clear(coeffs, size);
         goto fail;
     }
     gwy_math_choleski_solve(size, m, coeffs);
@@ -1261,6 +1346,257 @@ gwy_data_field_subtract_poly_max(GwyDataField *data_field,
                                           max_degree, coeffs);
 }
 
+/* Calculate integer powers by repeated squaring */
+static gdouble
+pow_int(gdouble x, guint n)
+{
+    gdouble v = 1.0;
+
+    while (n) {
+        if (n & 1)
+            v *= x;
+        x *= x;
+        n >>= 1;
+    }
+
+    return v;
+}
+
+/**
+ * gwy_data_field_area_fit_poly:
+ * @data_field: A data field.
+ * @mask_field: Mask of values to take values into account, or %NULL for full
+ *        @data_field.  Values equal to 0.0 and below cause corresponding
+ *        @data_field samples to be ignored, values equal to 1.0 and above
+ *        cause inclusion of corresponding @data_field samples.  The behaviour
+ *        for values inside (0.0, 1.0) is undefined (it may be specified
+ *        in the future).
+ * @col: Upper-left column coordinate.
+ * @row: Upper-left row coordinate.
+ * @width: Area width (number of columns).
+ * @height: Area height (number of rows).
+ * @nterms: The number of polynomial terms to take into account (twice the
+ *          number of items in @term_powers).
+ * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each
+ *               terms is described by a couple of powers (powerx, powery).
+ * @exclude: Interpret values @w in the mask as 1.0-@w.
+ * @coeffs: Array of size @nterms to store the coefficients to, or %NULL to
+ *          allocate a new array.
+ *
+ * Fit a given set of polynomial terms to a rectangular part of a data field.
+ *
+ * Returns: Either @coeffs if it was not %NULL, or a newly allocated array
+ *          with coefficients.
+ *
+ * Since: 2.11
+ **/
+gdouble*
+gwy_data_field_area_fit_poly(GwyDataField *data_field,
+                             GwyDataField *mask_field,
+                             gint col, gint row,
+                             gint width, gint height,
+                             gint nterms,
+                             const gint *term_powers,
+                             gboolean exclude,
+                             gdouble *coeffs)
+{
+    const gdouble *data, *mask;
+    gint xres, yres, r, c, i, j, k;
+    gdouble *m, *p;
+
+    g_return_val_if_fail(GWY_IS_DATA_FIELD(data_field), NULL);
+    g_return_val_if_fail(nterms >= 0, NULL);
+    g_return_val_if_fail(col >= 0 && row >= 0
+                         && col + width <= data_field->xres
+                         && row + height <= data_field->yres,
+                         NULL);
+    if (mask_field) {
+        g_return_val_if_fail(GWY_IS_DATA_FIELD(mask_field), NULL);
+        g_return_val_if_fail(mask_field->xres == data_field->xres
+                             && mask_field->yres == data_field->yres, NULL);
+    }
+
+    if (!nterms)
+        return coeffs;
+
+    data = data_field->data;
+    mask = mask_field ? mask_field->data : NULL;
+    xres = data_field->xres;
+    yres = data_field->yres;
+
+    if (!coeffs)
+        coeffs = g_new0(gdouble, nterms);
+
+    p = g_new(gdouble, nterms);
+    m = g_new0(gdouble, nterms*(nterms + 1)/2);
+
+    for (r = 0; r < height; r++) {
+        gdouble y = 2*r/(height - 1.0) - 1.0;
+        for (c = 0; c < width; c++) {
+            gdouble x = 2*c/(width - 1.0) - 1.0;
+            gdouble z = data[(row + r)*xres + (col + c)];
+            gdouble w = mask[(row + r)*xres + (col + c)];
+
+            if (exclude)
+                w = 1.0-w;
+
+            if (w <= 0.0)
+                continue;
+            if (w >= 1.0)
+                w = 1.0;
+
+            for (i = 0; i < nterms; i++) {
+                p[i] = pow_int(x, term_powers[2*i])
+                       * pow_int(y, term_powers[2*i + 1]);
+            }
+
+            k = 0;
+            for (i = 0; i < nterms; i++) {
+                for (j = 0; j <= i; j++)
+                    m[k++] += w*p[i]*p[j];
+                coeffs[i] += z*w*p[i];
+            }
+        }
+    }
+
+    if (!gwy_math_choleski_decompose(nterms, m))
+        gwy_clear(coeffs, nterms);
+    else
+        gwy_math_choleski_solve(nterms, m, coeffs);
+
+    g_free(p);
+    g_free(m);
+
+    return coeffs;
+}
+
+/**
+ * gwy_data_field_fit_poly:
+ * @data_field: A data field.
+ * @mask_field: Mask of values to take values into account, or %NULL for full
+ *        @data_field.  Values equal to 0.0 and below cause corresponding
+ *        @data_field samples to be ignored, values equal to 1.0 and above
+ *        cause inclusion of corresponding @data_field samples.  The behaviour
+ *        for values inside (0.0, 1.0) is undefined (it may be specified
+ *        in the future).
+ * @nterms: The number of polynomial terms to take into account (twice the
+ *          number of items in @term_powers).
+ * @term_powers: Array of size 2*@nterms describing the terms to fit.  Each
+ *               terms is described by a couple of powers (powerx, powery).
+ * @exclude: Interpret values @w in the mask as 1.0-@w.
+ * @coeffs: Array of size @nterms to store the coefficients to, or %NULL to
+ *          allocate a new array.
+ *
+ * Fit a given set of polynomial terms to a data field.
+ *
+ * Returns: Either @coeffs if it was not %NULL, or a newly allocated array
+ *          with coefficients.
+ *
+ * Since: 2.11
+ **/
+gdouble*
+gwy_data_field_fit_poly(GwyDataField *data_field,
+                        GwyDataField *mask_field,
+                        gint nterms,
+                        const gint *term_powers,
+                        gboolean exclude,
+                        gdouble *coeffs)
+{
+    g_return_val_if_fail(GWY_IS_DATA_FIELD(data_field), NULL);
+    return gwy_data_field_area_fit_poly(data_field, mask_field,
+                                        0, 0,
+                                        data_field->xres, data_field->yres,
+                                        nterms, term_powers, exclude,
+                                        coeffs);
+}
+
+/**
+ * gwy_data_field_area_subtract_poly:
+ * @data_field: A data field.
+ * @col: Upper-left column coordinate.
+ * @row: Upper-left row coordinate.
+ * @width: Area width (number of columns).
+ * @height: Area height (number of rows).
+ * @nterms: The number of polynomial terms to take into account (twice the
+ *          number of items in @term_powers).
+ * @term_powers: Array of size 2*@nterms describing the fitted terms.  Each
+ *               terms is described by a couple of powers (powerx, powery).
+ * @coeffs: Array of size @nterms to store with the coefficients.
+ *
+ * Subtract a given set of polynomial terms from a rectangular part of a data
+ * field.
+ *
+ * Since: 2.11
+ **/
+void
+gwy_data_field_area_subtract_poly(GwyDataField *data_field,
+                                  gint col, gint row,
+                                  gint width, gint height,
+                                  gint nterms,
+                                  const gint *term_powers,
+                                  const gdouble *coeffs)
+{
+    gdouble *data;
+    gint xres, yres, r, c, i;
+
+    g_return_if_fail(GWY_IS_DATA_FIELD(data_field));
+    g_return_if_fail(nterms >= 0);
+    g_return_if_fail(coeffs);
+    g_return_if_fail(col >= 0 && row >= 0
+                     && col + width <= data_field->xres
+                     && row + height <= data_field->yres);
+
+    if (!nterms)
+        return;
+
+    data = data_field->data;
+    xres = data_field->xres;
+    yres = data_field->yres;
+
+    for (r = 0; r < height; r++) {
+        gdouble y = 2*r/(height - 1.0) - 1.0;
+        for (c = 0; c < width; c++) {
+            gdouble x = 2*c/(width - 1.0) - 1.0;
+            gdouble z = data[(row + r)*xres + (col + c)];
+
+            for (i = 0; i < nterms; i++) {
+                z -= coeffs[i] * pow_int(x, term_powers[2*i])
+                     * pow_int(y, term_powers[2*i + 1]);
+            }
+
+            data[(row + r)*xres + (col + c)] = z;
+        }
+    }
+
+    gwy_data_field_invalidate(data_field);
+}
+
+/**
+ * gwy_data_field_subtract_poly:
+ * @data_field: A data field.
+ * @nterms: The number of polynomial terms to take into account (twice the
+ *          number of items in @term_powers).
+ * @term_powers: Array of size 2*@nterms describing the fitter terms.  Each
+ *               terms is described by a couple of powers (powerx, powery).
+ * @coeffs: Array of size @nterms to store with the coefficients.
+ *
+ * Subtract a given set of polynomial terms from a data field.
+ *
+ * Since: 2.11
+ **/
+void
+gwy_data_field_subtract_poly(GwyDataField *data_field,
+                             gint nterms,
+                             const gint *term_powers,
+                             const gdouble *coeffs)
+{
+    g_return_if_fail(GWY_IS_DATA_FIELD(data_field));
+    gwy_data_field_area_subtract_poly(data_field,
+                                      0, 0,
+                                      data_field->xres, data_field->yres,
+                                      nterms, term_powers, coeffs);
+}
+
 /**
  * gwy_data_field_area_fit_local_planes:
  * @data_field: A data field.
@@ -1302,7 +1638,6 @@ gwy_data_field_area_fit_local_planes(GwyDataField *data_field,
     gint xres, yres, ri, i, j, ii, jj;
 
     g_return_val_if_fail(GWY_IS_DATA_FIELD(data_field), NULL);
-    g_return_val_if_fail(coeffs, NULL);
     g_return_val_if_fail(size > 1, NULL);
     g_return_val_if_fail(col >= 0 && row >= 0
                      && width > 0 && height > 0
