@@ -1,5 +1,5 @@
 /*
- *  $Id: dmefile.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  $Id: dmefile.c 9136 2009-04-27 13:37:23Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -113,7 +113,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Danish Micro Engineering (DME) data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.3",
+    "0.4",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -205,11 +205,11 @@ dme_load(const gchar *filename,
     }
 
     /* Use negated positive conditions to catch NaNs */
-    if (!((dmefile.xreal = fabs(dmefile.xreal)) > 0)) {
+    if (!((dmefile.xreal = fabs(dmefile.x_calibration * dmefile.xreal)) > 0)) {
         g_warning("Real x size is 0.0, fixing to 1.0");
         dmefile.xreal = 1.0;
     }
-    if (!((dmefile.yreal = fabs(dmefile.yreal)) > 0)) {
+    if (!((dmefile.yreal = fabs(dmefile.y_calibration * dmefile.yreal)) > 0)) {
         g_warning("Real y size is 0.0, fixing to 1.0");
         dmefile.yreal = 1.0;
     }
@@ -223,8 +223,9 @@ dme_load(const gchar *filename,
            + dmefile.xres*dmefile.yres;
     for (i = 0; i < dmefile.yres; i++) {
         q = Angstrom * dmefile.height_scale_factor * pow(2.0, ls16[i] & 0x0f);
+        q *= dmefile.z_calibration;
         for (j = 0; j < dmefile.xres; j++) {
-            data[i*dmefile.xres + j]
+            data[i*dmefile.xres + (dmefile.xres-1 - j)]
                 = q*GINT16_FROM_LE(d16[i*dmefile.xres + j]);
         }
     }
@@ -325,4 +326,3 @@ dme_read_header(const guchar *p,
 }
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
-
