@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: err.h 8951 2009-01-02 12:01:30Z yeti-dn $
+ *  @(#) $Id: err.h 9037 2009-03-07 16:45:28Z yeti-dn $
  *  Copyright (C) 2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -158,6 +158,27 @@ err_CANCELLED(GError **error)
                 _("File import was cancelled by user."));
 }
 
+static inline gboolean
+require_keys(GHashTable *hash,
+             GError **error,
+             ...)
+{
+    va_list ap;
+    const gchar *key;
+
+    va_start(ap, error);
+    while ((key = va_arg(ap, const gchar *))) {
+        if (!g_hash_table_lookup(hash, key)) {
+            err_MISSING_FIELD(error, key);
+            va_end(ap);
+            return FALSE;
+        }
+    }
+    va_end(ap);
+
+    return TRUE;
+}
+
 #endif
 
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
