@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: intematix.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  @(#) $Id: intematix.c 9210 2009-06-07 22:23:45Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -121,7 +121,7 @@ static GwyModuleInfo module_info = {
     module_register,
     N_("Imports Intematix SDF data files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.2",
+    "0.3",
     "David Nečas (Yeti) & Petr Klapetek",
     "2006",
 };
@@ -146,6 +146,7 @@ isdf_detect(const GwyFileDetectInfo *fileinfo, gboolean only_name)
 {
     GwyTIFF *tiff;
     gint score = 0;
+    guint magic;
 
     if (only_name)
         return score;
@@ -155,17 +156,13 @@ isdf_detect(const GwyFileDetectInfo *fileinfo, gboolean only_name)
         || memcmp(fileinfo->head, MAGIC, MAGIC_SIZE) != 0)
         return 0;
 
-    if ((tiff = gwy_tiff_load(fileinfo->name, NULL))) {
-        const GwyTIFFEntry *entry;
+    if ((tiff = gwy_tiff_load(fileinfo->name, NULL))
+         && gwy_tiff_get_sint0(tiff, ISDF_TIFFTAG_FILEID, &magic)
+         && magic == ISDF_MAGIC_NUMBER)
+        score = 100;
 
-        if ((entry = gwy_tiff_find_tag(tiff, ISDF_TIFFTAG_FILEID))) {
-            const guchar *p = entry->value;
-
-            if (tiff->gets32(&p) == ISDF_MAGIC_NUMBER)
-                score = 100;
-        }
+    if (tiff)
         gwy_tiff_free(tiff);
-    }
 
     return score;
 }
@@ -190,7 +187,7 @@ isdf_load(const gchar *filename,
         return NULL;
 
     memset(&image, 0, sizeof(ISDFImage));
-    if (!gwy_tiff_get_sint(tiff, ISDF_TIFFTAG_FILEID, &magic)
+    if (!gwy_tiff_get_sint0(tiff, ISDF_TIFFTAG_FILEID, &magic)
         || magic != ISDF_MAGIC_NUMBER) {
         err_FILE_TYPE(error, "Intematix SDF");
         goto fail;
@@ -244,14 +241,14 @@ isdf_load(const gchar *filename,
         case GWY_TIFF_SLONG:
         for (i = 0; i < image.yres; i++) {
             for (j = 0; j < image.xres; j++)
-                data[i*image.xres + j] = q*tiff->gets32(&p);
+                data[i*image.xres + j] = q*tiff->get_gint32(&p);
         }
         break;
 
         case GWY_TIFF_DOUBLE:
         for (i = 0; i < image.yres; i++) {
             for (j = 0; j < image.xres; j++)
-                data[i*image.xres + j] = q*tiff->getdbl(&p);
+                data[i*image.xres + j] = q*tiff->get_gdouble(&p);
         }
         break;
 
@@ -289,17 +286,17 @@ isdf_image_fill_info(ISDFImage *image,
     const guchar *p;
 
     /* Required parameters */
-    if (!(gwy_tiff_get_uint(tiff, GWY_TIFFTAG_IMAGEWIDTH, &image->xres)
-          && gwy_tiff_get_uint(tiff, GWY_TIFFTAG_IMAGELENGTH, &image->yres)
-          && gwy_tiff_get_uint(tiff, ISDF_TIFFTAG_IMAGEDEPTH, &image->zres)
-          && gwy_tiff_get_uint(tiff, ISDF_TIFFTAG_FILETYPE, &image->file_type)
-          && gwy_tiff_get_uint(tiff, ISDF_TIFFTAG_DATATYPE, &image->data_type)
-          && gwy_tiff_get_float(tiff, ISDF_TIFFTAG_DATACNVT, &image->data_cnvt)
-          && gwy_tiff_get_string(tiff, ISDF_TIFFTAG_XDIMUNIT, &image->xunit)
-          && gwy_tiff_get_string(tiff, ISDF_TIFFTAG_YDIMUNIT, &image->yunit)
-          && gwy_tiff_get_string(tiff, ISDF_TIFFTAG_DATAUNIT, &image->dataunit)
-          && gwy_tiff_get_float(tiff, ISDF_TIFFTAG_IMGXDIM, &image->xreal)
-          && gwy_tiff_get_float(tiff, ISDF_TIFFTAG_IMGYDIM, &image->yreal))) {
+    if (!(gwy_tiff_get_uint0(tiff, GWY_TIFFTAG_IMAGE_WIDTH, &image->xres)
+          && gwy_tiff_get_uint0(tiff, GWY_TIFFTAG_IMAGE_LENGTH, &image->yres)
+          && gwy_tiff_get_uint0(tiff, ISDF_TIFFTAG_IMAGEDEPTH, &image->zres)
+          && gwy_tiff_get_uint0(tiff, ISDF_TIFFTAG_FILETYPE, &image->file_type)
+          && gwy_tiff_get_uint0(tiff, ISDF_TIFFTAG_DATATYPE, &image->data_type)
+          && gwy_tiff_get_float0(tiff, ISDF_TIFFTAG_DATACNVT, &image->data_cnvt)
+          && gwy_tiff_get_string0(tiff, ISDF_TIFFTAG_XDIMUNIT, &image->xunit)
+          && gwy_tiff_get_string0(tiff, ISDF_TIFFTAG_YDIMUNIT, &image->yunit)
+          && gwy_tiff_get_string0(tiff, ISDF_TIFFTAG_DATAUNIT, &image->dataunit)
+          && gwy_tiff_get_float0(tiff, ISDF_TIFFTAG_IMGXDIM, &image->xreal)
+          && gwy_tiff_get_float0(tiff, ISDF_TIFFTAG_IMGYDIM, &image->yreal))) {
         g_set_error(error, GWY_MODULE_FILE_ERROR, GWY_MODULE_FILE_ERROR_DATA,
                     _("Parameter tag set is incomplete."));
         return FALSE;
@@ -310,12 +307,12 @@ isdf_image_fill_info(ISDFImage *image,
         return FALSE;
     }
 
-    if (!(entry = gwy_tiff_find_tag(tiff, ISDF_TIFFTAG_SPMDATA))) {
+    if (!(entry = gwy_tiff_find_tag(tiff, 0, ISDF_TIFFTAG_SPMDATA))) {
         err_NO_DATA(error);
         return FALSE;
     }
     p = entry->value;
-    image->raw_data = tiff->data + tiff->getu32(&p);
+    image->raw_data = tiff->data + tiff->get_guint32(&p);
     image->raw_data_type = entry->type;
     image->raw_data_len = entry->count;
     if (image->raw_data_type != GWY_TIFF_SLONG
@@ -335,7 +332,7 @@ meta_add_string(GwyContainer *meta,
 {
     gchar *t;
 
-    if (!gwy_tiff_get_string(tiff, tag, &t))
+    if (!gwy_tiff_get_string0(tiff, tag, &t))
         return;
 
     g_strstrip(t);
@@ -404,17 +401,17 @@ isdf_get_metadata(const GwyTIFF *tiff,
     if (s)
         gwy_container_set_string_by_name(meta, "Data type", g_strdup(s));
 
-    meta_add_string(meta, tiff, GWY_TIFFTAG_IMAGEDESCRIPTION, "Description");
+    meta_add_string(meta, tiff, GWY_TIFFTAG_IMAGE_DESCRIPTION, "Description");
     meta_add_string(meta, tiff, GWY_TIFFTAG_SOFTWARE, "Software");
-    meta_add_string(meta, tiff, GWY_TIFFTAG_DATETIME, "Date");
+    meta_add_string(meta, tiff, GWY_TIFFTAG_DATE_TIME, "Date");
     meta_add_string(meta, tiff, ISDF_TIFFTAG_FILEINFO, "File information");
     meta_add_string(meta, tiff, ISDF_TIFFTAG_USERINFO, "User information");
     meta_add_string(meta, tiff, ISDF_TIFFTAG_SAMPLEINFO, "Sample information");
 
-    if (gwy_tiff_get_float(tiff, ISDF_TIFFTAG_SCANRATE, &v))
+    if (gwy_tiff_get_float0(tiff, ISDF_TIFFTAG_SCANRATE, &v))
         gwy_container_set_string_by_name(meta, "Scan rate",
                                          g_strdup_printf("%g line/s", v));
-    if (gwy_tiff_get_float(tiff, ISDF_TIFFTAG_BIASVOLTS, &v))
+    if (gwy_tiff_get_float0(tiff, ISDF_TIFFTAG_BIASVOLTS, &v))
         gwy_container_set_string_by_name(meta, "Bias",
                                          g_strdup_printf("%g V", v));
 
