@@ -1,5 +1,5 @@
 /*
- *  $Id: opdfile.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  $Id: opdfile.c 9166 2009-05-14 08:54:05Z yeti-dn $
  *  Copyright (C) 2008 David Necas (Yeti).
  *
  *  This program is free software; you can redistribute it and/or modify
@@ -121,6 +121,11 @@ static gboolean      get_float         (const OPDBlock *header,
                                         const gchar *name,
                                         gdouble *value,
                                         GError **error);
+static gboolean      get_int16         (const OPDBlock *header,
+                                        guint nblocks,
+                                        const gchar *name,
+                                        gint *value,
+                                        GError **error);
 static GwyDataField* get_data_field    (const OPDBlock *datablock,
                                         gdouble pixel_size,
                                         gdouble aspect,
@@ -151,8 +156,6 @@ static const guchar* get_array_params  (const guchar *p,
                                         guint *xres,
                                         guint *yres,
                                         OPDArrayType *type);
-static guint         remove_bad_data   (GwyDataField *dfield,
-                                        GwyDataField *mfield);
 static void          clone_meta        (GwyContainer *container,
                                         GwyContainer *meta,
                                         guint nchannels);
@@ -162,7 +165,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Imports Wyko OPD and ASC files."),
     "Yeti <yeti@gwyddion.net>",
-    "0.4",
+    "0.6",
     "David Nečas (Yeti)",
     "2008",
 };
@@ -218,7 +221,8 @@ opd_load(const gchar *filename,
     GwyDataField *dfield = NULL, *mfield = NULL;
     const guchar *p;
     guint nblocks, offset, i, j, k;
-    gdouble pixel_size, wavelength, mult = 1.0, aspect = 1.0;
+    gdouble pixel_size, wavelength, aspect = 1.0;
+    gint mult = 1;
 
     if (!gwy_file_get_contents(filename, &buffer, &size, &err)) {
         err_GET_FILE_CONTENTS(error, &err);
@@ -287,7 +291,7 @@ opd_load(const gchar *filename,
 
     wavelength *= Nanometer;
     pixel_size *= Milimeter;
-    get_float(header, nblocks, "Mult", &mult, NULL);
+    get_int16(header, nblocks, "Mult", &mult, NULL);
     get_float(header, nblocks, "Aspect", &aspect, NULL);
     wavelength /= mult;
 
@@ -409,6 +413,30 @@ get_float(const OPDBlock *header,
     return TRUE;
 }
 
+static gboolean
+get_int16(const OPDBlock *header,
+          guint nblocks,
+          const gchar *name,
+          gint *value,
+          GError **error)
+{
+    const guchar *p;
+    guint i;
+
+    if ((i = find_block(header, nblocks, name)) == nblocks) {
+        err_MISSING_FIELD(error, name);
+        return FALSE;
+    }
+    if (header[i].type != OPD_SHORT) {
+        err_INVALID(error, name);
+        return FALSE;
+    }
+    p = header[i].data;
+    *value = gwy_get_gint16_le(&p);
+    gwy_debug("%s = %d", name, *value);
+    return TRUE;
+}
+
 static GwyDataField*
 get_data_field(const OPDBlock *datablock,
                gdouble pixel_size, gdouble aspect, gdouble wavelength,
@@ -456,7 +484,7 @@ get_data_field(const OPDBlock *datablock,
         }
         else if (datatype == OPD_ARRAY_INT16) {
             for (j = yres; j; j--) {
-                guint v = gwy_get_guint16_le(&p);
+                gint v = gwy_get_gint16_le(&p);
                 if (v < OPD_BAD_INT16)
                     data[(j - 1)*xres + i] = wavelength*v;
                 else
@@ -476,7 +504,7 @@ get_data_field(const OPDBlock *datablock,
             return NULL;
         }
     }
-    mcount = remove_bad_data(dfield, mfield);
+    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
 
     if (maskfield && mcount)
         *maskfield = mfield;
@@ -869,7 +897,7 @@ get_asc_data_field(gchar **p,
         }
     }
 
-    mcount = remove_bad_data(dfield, mfield);
+    mcount = gwy_app_channel_remove_bad_data(dfield, mfield);
 
     if (maskfield && mcount)
         *maskfield = mfield;
@@ -886,36 +914,6 @@ fail:
 
 /***** Common *************************************************************/
 
-static guint
-remove_bad_data(GwyDataField *dfield, GwyDataField *mfield)
-{
-    gdouble *data = gwy_data_field_get_data(dfield);
-    gdouble *mdata = gwy_data_field_get_data(mfield);
-    gdouble *drow, *mrow;
-    gdouble avg;
-    guint i, j, mcount, xres, yres;
-
-    xres = gwy_data_field_get_xres(dfield);
-    yres = gwy_data_field_get_yres(dfield);
-    avg = gwy_data_field_area_get_avg(dfield, mfield, 0, 0, xres, yres);
-    mcount = 0;
-    for (i = 0; i < yres; i++) {
-        mrow = mdata + i*xres;
-        drow = data + i*xres;
-        for (j = 0; j < xres; j++) {
-            if (!mrow[j]) {
-                drow[j] = avg;
-                mcount++;
-            }
-            mrow[j] = 1.0 - mrow[j];
-        }
-    }
-
-    gwy_debug("mcount = %u", mcount);
-
-    return mcount;
-}
-
 static void
 clone_meta(GwyContainer *container, GwyContainer *meta, guint nchannels)
 {
