@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: rawfile.c 8950 2009-01-02 12:00:56Z yeti-dn $
+ *  @(#) $Id: rawfile.c 9311 2009-06-25 08:14:24Z yeti-dn $
  *  Copyright (C) 2003,2004 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -17,7 +17,6 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
-
 #include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
@@ -215,7 +214,7 @@ static GwyModuleInfo module_info = {
     N_("Imports raw data files, both ASCII and binary, according to "
        "user-specified format."),
     "Yeti <yeti@gwyddion.net>",
-    "2.5",
+    "2.6",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -240,6 +239,8 @@ static const GwyEnum builtin_menu[] = {
     { N_("Unsigned 16bit word"),  RAW_UNSIGNED_WORD16 },
     { N_("Signed 32bit word"),    RAW_SIGNED_WORD32   },
     { N_("Unsigned 32bit word"),  RAW_UNSIGNED_WORD32 },
+    { N_("Signed 64bit word"),    RAW_SIGNED_WORD64   },
+    { N_("Unsigned 64bit word"),  RAW_UNSIGNED_WORD64 },
     { N_("IEEE single"),          RAW_IEEE_FLOAT      },
     { N_("IEEE double"),          RAW_IEEE_DOUBLE     },
 };
@@ -748,7 +749,7 @@ rawfile_dialog_format_page(RawFileArgs *args,
     adj = gtk_adjustment_new(args->p.skipfields, 0, 1 << 30, 1, 10, 0);
     controls->skipfields = gwy_table_attach_spinbutton(table, row,
                                                        _("E_ach row skip:"),
-                                                       "fields", adj);
+                                                       _("fields"), adj);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(controls->skipfields), 0);
     row++;
 
@@ -817,14 +818,14 @@ rawfile_dialog_format_page(RawFileArgs *args,
     adj = gtk_adjustment_new(args->p.offset, 0, 1 << 30, 16, 1024, 0);
     controls->offset = gwy_table_attach_spinbutton(table, row,
                                                    _("Start at _offset:"),
-                                                   "bytes", adj);
+                                                   _("bytes"), adj);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(controls->offset), 0);
     row++;
 
     adj = gtk_adjustment_new(args->p.size, 1, 24, 1, 8, 0);
     controls->size = gwy_table_attach_spinbutton(table, row,
                                                  _("_Sample size:"),
-                                                 "bits", adj);
+                                                 _("bits"), adj);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(controls->size), 0);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(controls->size), TRUE);
     row++;
@@ -832,7 +833,7 @@ rawfile_dialog_format_page(RawFileArgs *args,
     adj = gtk_adjustment_new(args->p.skip, 0, 1 << 30, 1, 8, 0);
     controls->skip = gwy_table_attach_spinbutton(table, row,
                                                  _("After each sample s_kip:"),
-                                                 "bits", adj);
+                                                 _("bits"), adj);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(controls->skip), 0);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(controls->skip), TRUE);
     row++;
@@ -840,7 +841,7 @@ rawfile_dialog_format_page(RawFileArgs *args,
     adj = gtk_adjustment_new(args->p.rowskip, 0, 1 << 30, 1, 8, 0);
     controls->rowskip = gwy_table_attach_spinbutton(table, row,
                                                     _("After each _row skip:"),
-                                                    "bits", adj);
+                                                    _("bits"), adj);
     gtk_spin_button_set_digits(GTK_SPIN_BUTTON(controls->rowskip), 0);
     gtk_spin_button_set_snap_to_ticks(GTK_SPIN_BUTTON(controls->rowskip), TRUE);
     row++;
@@ -1370,10 +1371,15 @@ preview_cb(RawFileControls *controls)
 {
     GwyDataField *dfield;
     GdkPixbuf *pixbuf, *pixbuf2;
+    GtkWidget *entry;
     gint xres, yres;
     gdouble zoom, avg, rms;
 
     rawfile_warn_clear(controls);
+    entry = gtk_window_get_focus(GTK_WINDOW(controls->dialog));
+    if (entry && GTK_IS_ENTRY(entry))
+        gtk_widget_activate(entry);
+
     update_dialog_values(controls);
     if (!(dfield = rawfile_read_data_field(controls,
                                            controls->args,
@@ -1955,7 +1961,13 @@ rawfile_read_builtin(RawFileArgs *args,
 {
     guchar *rtable8 = NULL;
     guint i, j, k, size, skip, rowskip;
-    double good_alignment;
+    union {
+        gint8 i8; guint8 u8;
+        gint16 i16; guint16 u16;
+        gint32 i32; guint32 u32;
+        gint64 i64; guint64 u64;
+        gfloat f; gdouble d;
+    } good_alignment;
     guchar *b;
 
     g_assert(args->p.builtin > RAW_NONE && args->p.builtin < RAW_LAST);
@@ -1991,35 +2003,52 @@ rawfile_read_builtin(RawFileArgs *args,
             /* now interpret b as a number in HOST order */
             switch (args->p.builtin) {
                 case RAW_SIGNED_BYTE:
-                *(data++) = (gdouble)(gchar)b[0];
+                *(data++) = (gdouble)good_alignment.i8;
                 break;
 
                 case RAW_UNSIGNED_BYTE:
-                *(data++) = (gdouble)b[0];
+                *(data++) = (gdouble)good_alignment.u8;
                 break;
 
                 case RAW_SIGNED_WORD16:
-                *(data++) = (gdouble)*(gint16*)b;
+                *(data++) = (gdouble)good_alignment.i16;
                 break;
 
                 case RAW_UNSIGNED_WORD16:
-                *(data++) = (gdouble)*(guint16*)b;
+                *(data++) = (gdouble)good_alignment.u16;
                 break;
 
                 case RAW_SIGNED_WORD32:
-                *(data++) = (gdouble)*(gint32*)b;
+                *(data++) = (gdouble)good_alignment.i32;
                 break;
 
                 case RAW_UNSIGNED_WORD32:
-                *(data++) = (gdouble)*(guint32*)b;
+                *(data++) = (gdouble)good_alignment.u32;
                 break;
 
                 case RAW_IEEE_FLOAT:
-                *(data++) = *(float*)b;
+                *(data++) = (gdouble)good_alignment.f;
                 break;
 
                 case RAW_IEEE_DOUBLE:
-                *(data++) = *(double*)b;
+                *(data++) = (gdouble)good_alignment.d;
+                break;
+
+                case RAW_SIGNED_WORD64:
+                *(data++) = (gdouble)good_alignment.i64;
+                break;
+
+                case RAW_UNSIGNED_WORD64:
+                /* Fucking MSVC6 cannot convert unsigned 64bit int to double. */
+#ifdef _MSC_VER
+                {
+                    guint u32h = good_alignment.u64 >> 32u;
+                    guint u32l = good_alignment.u64 & 0xffffffffu;
+                    *(data++) = 4294967296.0*u32h + u32l;
+                }
+#else
+                *(data++) = (gdouble)good_alignment.u64;
+#endif
                 break;
 
                 default:
