@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: shimadzu.c 8916 2008-12-30 12:48:54Z yeti-dn $
+ *  @(#) $Id: shimadzu.c 9037 2009-03-07 16:45:28Z yeti-dn $
  *  Copyright (C) 2007 David Necas (Yeti).
  *  E-mail: yeti@gwyddion.net.
  *
@@ -84,9 +84,6 @@ static gboolean      get_scales           (GHashTable *hash,
                                            GwySIUnit *si_unit_z,
                                            GError **error);
 static GwyContainer* shimadzu_get_metadata(GHashTable *hash);
-static gboolean      require_keys         (GHashTable *hash,
-                                           GError **error,
-                                           ...);
 
 static GwyModuleInfo module_info = {
     GWY_MODULE_ABI_VERSION,
@@ -560,25 +557,4 @@ shimadzu_get_metadata(GHashTable *hash)
     return meta;
 }
 
-static gboolean
-require_keys(GHashTable *hash,
-             GError **error,
-             ...)
-{
-    va_list ap;
-    const gchar *key;
-
-    va_start(ap, error);
-    while ((key = va_arg(ap, const gchar *))) {
-        if (!g_hash_table_lookup(hash, key)) {
-            err_MISSING_FIELD(error, key);
-            va_end(ap);
-            return FALSE;
-        }
-    }
-    va_end(ap);
-
-    return TRUE;
-}
-
 /* vim: set cin et ts=4 sw=4 cino=>1s,e0,n0,f0,{0,}0,^0,\:1s,=0,g1s,h0,t0,+1s,c3,(0,u0 : */
