@@ -1,3 +1,33 @@
+/*
+ *  IonScope SICM file format importer
+ *  Copyright (C) 2008 Matthew Caldwell.
+ *  E-mail: m.caldwell@ucl.ac.uk
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
+ */
+
+/**
+ * [FILE-MAGIC-FREEDESKTOP]
+ * <mime-type type="application/x-sicm-spm">
+ *   <comment>IonScope SICM data</comment>
+ *   <magic priority="50">
+ *     <match type="string" offset="0" value="\x32\x00"/>
+ *   </magic>
+ * </mime-type>
+ **/
+
 /*--------------------------------------------------------------------------
   Dependencies
 ----------------------------------------------------------------------------*/
@@ -213,7 +243,6 @@ static GwyContainer* sicm_load ( const gchar *filename,
     if (!gwy_file_get_contents(filename, &buffer, &size, &err))
     {
         err_GET_FILE_CONTENTS(error, &err);
-        g_clear_error(&err);
         return NULL;
     }
 
