@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: profile.c 8993 2009-02-04 11:24:11Z yeti-dn $
+ *  @(#) $Id: profile.c 9023 2009-02-27 10:48:18Z yeti-dn $
  *  Copyright (C) 2003-2006 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -19,6 +19,7 @@
  */
 
 #include "config.h"
+#include <stdlib.h>
 #include <gtk/gtk.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
@@ -38,7 +39,7 @@
 #define GWY_TOOL_PROFILE_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS((obj), GWY_TYPE_TOOL_PROFILE, GwyToolProfileClass))
 
 enum {
-    NLINES = 18,
+    NLINES = 1024,
     MAX_THICKNESS = 128,
     MIN_RESOLUTION = 4,
     MAX_RESOLUTION = 16384
@@ -129,7 +130,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Profile tool, creates profile graphs from selected lines."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.9",
+    "2.11",
     "David Nečas (Yeti) & Petr Klapetek",
     "2004",
 };
@@ -524,7 +525,7 @@ gwy_tool_profile_update_curve(GwyToolProfile *tool,
     yl2 = floor(gwy_data_field_rtoi(plain_tool->data_field, line[3]));
 
     if (!tool->args.fixres) {
-        lineres = GWY_ROUND(hypot(xl1 - xl2 + 1, yl1 - yl2 + 1));
+        lineres = GWY_ROUND(hypot(abs(xl1 - xl2) + 1, abs(yl1 - yl2) + 1));
         lineres = MAX(lineres, MIN_RESOLUTION);
     }
     else
