@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: roughness.c 8993 2009-02-04 11:24:11Z yeti-dn $
+ *  @(#) $Id: roughness.c 9057 2009-03-11 10:56:52Z yeti-dn $
  *  Copyright (C) 2006-2008 Martin Hason, David Necas (Yeti), Petr Klapetek.
  *  E-mail: hasonm@physics.muni.cz, yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -18,7 +18,9 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111 USA
  */
 
+#include "config.h"
 #include <string.h>
+#include <stdlib.h>
 #include <gtk/gtk.h>
 #include <libgwyddion/gwymacros.h>
 #include <libgwyddion/gwymath.h>
@@ -630,7 +632,7 @@ static GwyModuleInfo module_info = {
     N_("Calculate surface profile parameters."),
     "Martin Hasoň <hasonm@physics.muni.cz>, "
         "Yeti <yeti@gwyddion.net>",
-    "1.4",
+    "1.6",
     "Martin Hasoň & David Nečas (Yeti)",
     "2006",
 };
@@ -939,7 +941,7 @@ render_name(G_GNUC_UNUSED GtkTreeViewColumn *column,
     g_object_set(renderer,
                  "ellipsize", header ? PANGO_ELLIPSIZE_NONE : PANGO_ELLIPSIZE_END ,
                  "weight", header ? PANGO_WEIGHT_BOLD : PANGO_WEIGHT_NORMAL,
-                 "text", pinfo->name,
+                 "text", gettext(pinfo->name),
                  NULL);
 }
 
@@ -1285,7 +1287,7 @@ gwy_tool_roughness_update(GwyToolRoughness *tool)
     xl2 = floor(gwy_data_field_rtoj(plain_tool->data_field, line[2]));
     yl2 = floor(gwy_data_field_rtoi(plain_tool->data_field, line[3]));
 
-    lineres = ROUND(hypot(xl1 - xl2, yl1 - yl2));
+    lineres = ROUND(hypot(abs(xl1 - xl2) + 1, abs(yl1 - yl2) + 1));
     if (lineres < 8)
         return;
 
@@ -1416,7 +1418,7 @@ gwy_tool_roughness_update_graphs(GwyToolRoughness *tool)
             g_object_set(gcmodel,
                          "mode", GWY_GRAPH_CURVE_LINE,
                          "color", gwy_graph_get_preset_color(i),
-                         "description", graph->title,
+                         "description", gettext(graph->title),
                          NULL);
             gwy_graph_model_add_curve(gmodel, gcmodel);
             g_object_unref(gcmodel);
@@ -2283,7 +2285,7 @@ gwy_tool_roughness_create_report(gpointer user_data,
         gchar *sym;
 
         if (pinfo->param == -1) {
-            g_string_append_printf(report, "\n%s\n", pinfo->name);
+            g_string_append_printf(report, "\n%s\n", gettext(pinfo->name));
             continue;
         }
 
