@@ -1,5 +1,5 @@
 /*
- *  @(#) $Id: stats.c 8879 2008-12-28 12:16:59Z yeti-dn $
+ *  @(#) $Id: stats.c 8993 2009-02-04 11:24:11Z yeti-dn $
  *  Copyright (C) 2003-2008 David Necas (Yeti), Petr Klapetek.
  *  E-mail: yeti@gwyddion.net, klapetek@gwyddion.net.
  *
@@ -25,6 +25,7 @@
 #include <glib/gstdio.h>
 #include <gtk/gtk.h>
 #include <libgwyddion/gwymacros.h>
+#include <libgwyddion/gwymath.h>
 #include <libgwymodule/gwymodule-tool.h>
 #include <libprocess/datafield.h>
 #include <libprocess/stats.h>
@@ -60,6 +61,7 @@ typedef struct {
     gdouble kurtosis;
     gdouble area;
     gdouble projarea;
+    /* These two are in degrees as we use need only for the user. */
     gdouble theta;
     gdouble phi;
 } ToolResults;
@@ -152,7 +154,7 @@ static GwyModuleInfo module_info = {
     &module_register,
     N_("Statistics tool."),
     "Petr Klapetek <klapetek@gwyddion.net>",
-    "2.8",
+    "2.10",
     "David Nečas (Yeti) & Petr Klapetek",
     "2003",
 };
@@ -389,7 +391,7 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
     hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(dialog->vbox), hbox, FALSE, FALSE, 0);
     tool->aux_box = GTK_BOX(hbox);
-  
+
     tool->save = gwy_tool_stats_add_aux_button(tool, GTK_STOCK_SAVE,
                                                _("Save table to a file"));
     g_signal_connect_swapped(tool->save, "clicked",
@@ -397,7 +399,7 @@ gwy_tool_stats_init_dialog(GwyToolStats *tool)
 
     tool->copy = gwy_tool_stats_add_aux_button(tool, GTK_STOCK_COPY,
                                                _("Copy table to clipboard"));
-    g_signal_connect_swapped(tool->save, "clicked",
+    g_signal_connect_swapped(tool->copy, "clicked",
                              G_CALLBACK(gwy_tool_stats_copy), tool);
 
     tool->update = gtk_dialog_add_button(dialog, _("_Update"),
@@ -577,10 +579,8 @@ gwy_tool_stats_update_labels(GwyToolStats *tool)
         gtk_label_set_text(GTK_LABEL(tool->area), _("N.A."));
 
     if (tool->same_units && !mask_in_use) {
-        update_label(tool->angle_format, tool->theta,
-                     180.0/G_PI * tool->results.theta);
-        update_label(tool->angle_format, tool->phi,
-                     180.0/G_PI * tool->results.phi);
+        update_label(tool->angle_format, tool->theta, tool->results.theta);
+        update_label(tool->angle_format, tool->phi, tool->results.phi);
     }
     else {
         gtk_label_set_text(GTK_LABEL(tool->theta), _("N.A."));
@@ -611,10 +611,10 @@ gwy_tool_stats_calculate(GwyToolStats *tool)
         sel[3] = gwy_data_field_get_yreal(plain_tool->data_field);
     }
     else {
-        isel[0] = gwy_data_field_rtoj(plain_tool->data_field, sel[0]);
-        isel[1] = gwy_data_field_rtoi(plain_tool->data_field, sel[1]);
-        isel[2] = gwy_data_field_rtoj(plain_tool->data_field, sel[2]);
-        isel[3] = gwy_data_field_rtoi(plain_tool->data_field, sel[3]);
+        isel[0] = floor(gwy_data_field_rtoj(plain_tool->data_field, sel[0]));
+        isel[1] = floor(gwy_data_field_rtoi(plain_tool->data_field, sel[1]));
+        isel[2] = floor(gwy_data_field_rtoj(plain_tool->data_field, sel[2]));
+        isel[3] = floor(gwy_data_field_rtoi(plain_tool->data_field, sel[3]));
         w = ABS(isel[2] - isel[0]) + 1;
         h = ABS(isel[3] - isel[1]) + 1;
         isel[0] = MIN(isel[0], isel[2]);
@@ -666,6 +666,8 @@ gwy_tool_stats_calculate(GwyToolStats *tool)
                                             isel[0], isel[1], w, h,
                                             &tool->results.theta,
                                             &tool->results.phi);
+        tool->results.theta *= 180.0/G_PI;
+        tool->results.phi *= 180.0/G_PI;
     }
 
     memcpy(tool->results.isel, isel, sizeof(isel));
@@ -750,7 +752,6 @@ gwy_tool_stats_copy(GwyToolStats *tool)
     ToolReportData report_data;
     GtkClipboard *clipboard;
     GdkDisplay *display;
-    GdkAtom atom;
     gssize len;
     gchar *text;
 
@@ -768,9 +769,8 @@ gwy_tool_stats_copy(GwyToolStats *tool)
     report_data.id = plain_tool->id;
 
     text = gwy_tool_stats_create_report(&report_data, &len);
-    atom = gdk_atom_intern("CLIPBOARD", FALSE);
     display = gtk_widget_get_display(GTK_WIDGET(GWY_TOOL(tool)->dialog));
-    clipboard = gtk_clipboard_get_for_display(display, atom);
+    clipboard = gtk_clipboard_get_for_display(display, GDK_SELECTION_CLIPBOARD);
     gtk_clipboard_set_text(clipboard, text, -1);
     g_free(text);
 }
