@@ -1,6 +1,6 @@
 #!/usr/bin/python
 # Written by Yeti <yeti@gwyddion.net>. Public domain.
-# @(#) $Id: update-msvc.py 8742 2008-07-18 07:00:07Z yeti-dn $
+# @(#) $Id: update-msvc.py 9227 2009-06-09 07:30:11Z yeti-dn $
 import re, os, sys, shutil, glob, time
 
 # The value part of a Makefile assignment with line continuations
@@ -346,7 +346,7 @@ def check_make_all():
 
 def check_completness(config):
     """Check if optional features that can affect completnes are enabled."""
-    must_have = 'HAVE_TIFF', 'HAVE_XML2', 'HAVE_GTKGLEXT'
+    must_have = 'HAVE_XML2', 'HAVE_GTKGLEXT'
     text = get_file(config)
     ok = True
     for x in must_have:
